@@ -447,7 +447,7 @@ static void figure_auth_funcs(struct perm_cfg_st *config, char **auth, unsigned
 				if (c_strncasecmp(auth[j], avail_auth_types[i].name, avail_auth_types[i].name_size) == 0) {
 					if (avail_auth_types[i].get_brackets_string)
 						config->auth[x].additional = avail_auth_types[i].get_brackets_string(config, auth[j]+avail_auth_types[i].name_size);
-				
+
 					config->auth[x].name = talloc_strdup(config, avail_auth_types[i].name);
 					fprintf(stderr, NOTESTR"enabling '%s' as authentication method\n", avail_auth_types[i].name);
 
@@ -801,9 +801,7 @@ size_t urlfw_size = 0;
 
 	READ_STRING("ocsp-response", config->ocsp_response);
 
-#ifdef ANYCONNECT_CLIENT_COMPAT
 	READ_STRING("user-profile", config->xml_config_file);
-#endif
 
 	READ_STRING("default-domain", config->default_domain);
 	READ_STRING("crl", config->crl);
@@ -1155,6 +1153,13 @@ static void check_cfg(struct perm_cfg_st *perm_config)
 		exit(1);
 	}
 
+	if (perm_config->config->cert_req != 0 && perm_config->config->cert_user_oid != NULL) {
+		if (!c_isdigit(perm_config->config->cert_user_oid[0]) && strcmp(perm_config->config->cert_user_oid, "SAN(rfc822name)") != 0) {
+			fprintf(stderr, ERRSTR"the option 'cert-user-oid' has a unsupported value\n");
+			exit(1);
+		}
+	}
+
 	if (perm_config->unix_conn_file != NULL && (perm_config->config->cert_req != 0)) {
 		if (perm_config->config->listen_proxy_proto == 0) {
 			fprintf(stderr, ERRSTR"the option 'listen-clear-file' cannot be combined with 'auth=certificate'\n");
@@ -1162,7 +1167,6 @@ static void check_cfg(struct perm_cfg_st *perm_config)
 		}
 	}
 
-#ifdef ANYCONNECT_CLIENT_COMPAT
 	if (perm_config->cert && perm_config->cert_hash == NULL) {
 		perm_config->cert_hash = calc_sha1_hash(perm_config, perm_config->cert[0], 1);
 	}
@@ -1185,7 +1189,6 @@ static void check_cfg(struct perm_cfg_st *perm_config)
 			exit(1);
 		}
 	}
-#endif
 
 	if (perm_config->config->keepalive == 0)
 		perm_config->config->keepalive = 3600;
@@ -1271,35 +1274,47 @@ void clear_cfg(struct perm_cfg_st* perm_config)
 	return;
 }
 
+static void append(const char *option)
+{
+	static int have_previous_val = 0;
+
+	if (have_previous_val == 0) {
+		have_previous_val = 1;
+	} else {
+		fprintf(stderr, ", ");
+	}
+	fprintf(stderr, "%s", option);
+}
+
 void print_version(tOptions *opts, tOptDesc *desc)
 {
 	const char *p;
 
 	fputs(OCSERV_FULL_VERSION, stderr);
-	fprintf(stderr, "\n\nCompiled with ");
+	fprintf(stderr, "\n\nCompiled with: ");
 #ifdef HAVE_LIBSECCOMP
-	fprintf(stderr, "seccomp, ");
+	append("seccomp");
 #endif
 #ifdef HAVE_LIBWRAP
-	fprintf(stderr, "tcp-wrappers, ");
+	append("tcp-wrappers");
 #endif
 #ifdef HAVE_LIBOATH
-	fprintf(stderr, "oath, ");
+	append("oath");
 #endif
 #ifdef HAVE_RADIUS
-	fprintf(stderr, "radius, ");
+	append("radius");
 #endif
 #ifdef HAVE_GSSAPI
-	fprintf(stderr, "gssapi, ");
+	append("gssapi");
 #endif
 #ifdef HAVE_PAM
-	fprintf(stderr, "PAM, ");
+	append("PAM");
 #endif
 #ifdef HAVE_PKCS11
-	fprintf(stderr, "PKCS#11, ");
+	append("PKCS#11");
 #endif
 #ifdef ANYCONNECT_CLIENT_COMPAT
-	fprintf(stderr, "AnyConnect, ");
+	append("AnyConnect");
 #endif
 	fprintf(stderr, "\n");
 
