@@ -488,7 +488,7 @@ static void update_fd_limits(main_server_st *s, unsigned main)
 
 		if (max > def_set.rlim_cur) {
 			new_set.rlim_cur = max;
-			new_set.rlim_max = new_set.rlim_cur;
+			new_set.rlim_max = def_set.rlim_max;
 			ret = setrlimit(RLIMIT_NOFILE, &new_set);
 			if (ret < 0) {
 				fprintf(stderr, "error in setrlimit(%u): %s (cur: %u)\n", max, strerror(errno), (unsigned)def_set.rlim_cur);
@@ -498,7 +498,7 @@ static void update_fd_limits(main_server_st *s, unsigned main)
 		/* set limits for worker processes */
 		ret = setrlimit(RLIMIT_NOFILE, &def_set);
 		if (ret < 0) {
-			fprintf(stderr, "error in setrlimit(%u): %s\n", (unsigned)def_set.rlim_cur, strerror(errno));
+			mslog(s, NULL, LOG_INFO, "cannot update file limit(%u): %s\n", (unsigned)def_set.rlim_cur, strerror(errno));
 		}
 	}
 #endif
