@@ -48,6 +48,10 @@
 #include <vpn.h>
 #include <base64-helper.h>
 
+/* In JSON output include fields which were no longer available after 0.11.7
+ */
+#define OCSERV_0_11_6_COMPAT 1
+
 static
 int common_info_cmd(UserListRep *args, FILE *out, cmd_params_st *params);
 static
@@ -611,15 +615,18 @@ int handle_list_users_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *
 	return ret;
 }
 
-static char *cookie_to_str(void *cookie, unsigned cookie_size, unsigned small)
+static char *shorten(void *cookie, unsigned cookie_size, unsigned small)
 {
-	static char psid[BASE64_ENCODE_RAW_LENGTH(SID_SIZE) + 1];
+	static char psid[SAFE_ID_SIZE];
 
-	assert(cookie_size == SID_SIZE);
-	oc_base64_encode((char *)cookie, cookie_size, (char *)psid, sizeof(psid));
+	assert(cookie_size <= SAFE_ID_SIZE);
+	memcpy(psid, cookie, cookie_size);
 
 	if (small)
 		psid[6] = 0;
+	else
+		psid[SAFE_ID_SIZE-1] = 0;
+
 	return psid;
 }
 
@@ -647,7 +654,7 @@ void cookie_list(struct unix_ctx *ctx, SecmListCookiesReplyMsg *rep, FILE *out,
 		/* add header */
 		if (i == 0) {
 			fprintf(out, "%6s %8s %8s %14s %24s %8s %8s\n",
-				"cookie", "user", "group", "ip", "user agent", "updated", "status");
+				"session", "user", "group", "ip", "user agent", "updated", "status");
 		}
 
 		t = rep->cookies[i]->last_modified;
@@ -665,7 +672,7 @@ void cookie_list(struct unix_ctx *ctx, SecmListCookiesReplyMsg *rep, FILE *out,
 
 
 		fprintf(out, "%.6s %8s %8s %14s %.24s %8s %8s\n",
-			cookie_to_str(rep->cookies[i]->sid.data, rep->cookies[i]->sid.len, 1),
+			shorten(rep->cookies[i]->safe_id.data, rep->cookies[i]->safe_id.len, 1),
 			username, groupname, rep->cookies[i]->remote_ip,
 			rep->cookies[i]->user_agent, tmpbuf, ps_status_to_str(rep->cookies[i]->status, 1));
 	}
@@ -1029,9 +1036,15 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 		print_time_ival7(tmpbuf, time(0), t);
 		print_single_value_ex(out, params, "Connected at", str_since, tmpbuf, 1);
 
-		if (HAVE_JSON(params))
-			print_single_value(out, params, "Raw cookie", cookie_to_str(args->user[i]->sid.data, args->user[i]->sid.len, 0), 1);
-		print_single_value(out, params, "Cookie", cookie_to_str(args->user[i]->sid.data, args->user[i]->sid.len, 1), 1);
+		if (HAVE_JSON(params)) {
+			print_single_value(out, params, "Full session", shorten(args->user[i]->safe_id.data, args->user[i]->safe_id.len, 0), 1);
+#ifdef OCSERV_0_11_6_COMPAT
+			/* compat with previous versions */
+			print_single_value(out, params, "Raw cookie", shorten(args->user[i]->safe_id.data, args->user[i]->safe_id.len, 0), 1);
+			print_single_value(out, params, "Cookie", shorten(args->user[i]->safe_id.data, args->user[i]->safe_id.len, 1), 1);
+#endif
+		}
+		print_single_value(out, params, "Session", shorten(args->user[i]->safe_id.data, args->user[i]->safe_id.len, 1), 1);
 
 		print_single_value(out, params, "TLS ciphersuite", args->user[i]->tls_ciphersuite, 1);
 		print_single_value(out, params, "DTLS cipher", args->user[i]->dtls_ciphersuite, 1);
@@ -1148,8 +1161,15 @@ int cookie_info_cmd(SecmListCookiesReplyMsg * args, FILE *out, cmd_params_st *pa
 
 		print_single_value(out, params, "Last Modified", str_since, 1);
 
-		print_single_value(out, params, "Raw cookie", cookie_to_str(args->cookies[i]->sid.data, args->cookies[i]->sid.len, 0), 1);
-		print_single_value(out, params, "Cookie", cookie_to_str(args->cookies[i]->sid.data, args->cookies[i]->sid.len, 1), 1);
+#ifdef OCSERV_0_11_6_COMPAT
+		if (HAVE_JSON(params)) {
+			/* compat with previous versions */
+			print_single_value(out, params, "Raw cookie", shorten(args->cookies[i]->safe_id.data, args->cookies[i]->safe_id.len, 0), 1);
+			print_single_value(out, params, "Cookie", shorten(args->cookies[i]->safe_id.data, args->cookies[i]->safe_id.len, 1), 1);
+		}
+#endif
+		print_single_value(out, params, "Full session", shorten(args->cookies[i]->safe_id.data, args->cookies[i]->safe_id.len, 0), 1);
+		print_single_value(out, params, "Session", shorten(args->cookies[i]->safe_id.data, args->cookies[i]->safe_id.len, 1), 1);
 
 		print_end_block(out, params, i<(args->n_cookies-1)?1:0);
 
