@@ -197,7 +197,7 @@ static int check_cert_user_group_status(sec_mod_st * sec, client_entry_st * e)
 	if (e->auth_type & AUTH_TYPE_CERTIFICATE) {
 		if (e->tls_auth_ok == 0) {
 			seclog(sec, LOG_INFO, "user %s "SESSION_STR" presented no certificate; rejecting",
-			       e->acct_info.username, e->acct_info.psid);
+			       e->acct_info.username, e->acct_info.safe_id);
 			return -1;
 		}
 
@@ -214,7 +214,7 @@ static int check_cert_user_group_status(sec_mod_st * sec, client_entry_st * e)
 			if (sec->config->cert_user_oid != NULL && e->cert_user_name[0] && strcmp(e->acct_info.username, e->cert_user_name) != 0) {
 				seclog(sec, LOG_INFO,
 				       "user '%s' "SESSION_STR" presented a certificate which is for user '%s'; rejecting",
-				       e->acct_info.username, e->acct_info.psid, e->cert_user_name);
+				       e->acct_info.username, e->acct_info.safe_id, e->cert_user_name);
 				return -1;
 			}
 
@@ -229,7 +229,7 @@ static int check_cert_user_group_status(sec_mod_st * sec, client_entry_st * e)
 				if (found == 0) {
 					seclog(sec, LOG_INFO,
 						"user '%s' "SESSION_STR" presented a certificate from group '%s' but he isn't a member of it; rejecting",
-						e->acct_info.username, e->acct_info.psid, e->acct_info.groupname);
+						e->acct_info.username, e->acct_info.safe_id, e->acct_info.groupname);
 						return -1;
 				}
 			}
@@ -425,19 +425,17 @@ int handle_secm_session_open_cmd(sec_mod_st *sec, int fd, const SecmSessionOpenM
 
 	e = find_client_entry(sec, req->sid.data);
 	if (e == NULL) {
-		char tmp[BASE64_ENCODE_RAW_LENGTH(SID_SIZE) + 1];
-		oc_base64_encode((char *)req->sid.data, req->sid.len, (char *)tmp, sizeof(tmp));
-		seclog(sec, LOG_INFO, "session open but with non-existing SID: %s!", tmp);
+		seclog(sec, LOG_INFO, "session open but with non-existing SID!");
 		return send_failed_session_open_reply(sec, fd);
 	}
 
 	if (e->status != PS_AUTH_COMPLETED) {
-		seclog(sec, LOG_ERR, "session open received in unauthenticated client %s "SESSION_STR"!", e->acct_info.username, e->acct_info.psid);
+		seclog(sec, LOG_ERR, "session open received in unauthenticated client %s "SESSION_STR"!", e->acct_info.username, e->acct_info.safe_id);
 		return send_failed_session_open_reply(sec, fd);
 	}
 
 	if IS_CLIENT_ENTRY_EXPIRED(sec, e, time(0)) {
-		seclog(sec, LOG_ERR, "session expired; denied session for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.psid);
+		seclog(sec, LOG_ERR, "session expired; denied session for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.safe_id);
 		e->status = PS_AUTH_FAILED;
 		return send_failed_session_open_reply(sec, fd);
 	}
@@ -451,7 +449,7 @@ int handle_secm_session_open_cmd(sec_mod_st *sec, int fd, const SecmSessionOpenM
 		ret = sec->perm_config->acct.amod->open_session(e->auth_type, &e->acct_info, req->sid.data, req->sid.len);
 		if (ret < 0) {
 			e->status = PS_AUTH_FAILED;
-			seclog(sec, LOG_INFO, "denied session for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.psid);
+			seclog(sec, LOG_INFO, "denied session for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.safe_id);
 			return send_failed_session_open_reply(sec, fd);
 		} else {
 			e->session_is_open = 1;
@@ -485,7 +483,7 @@ int handle_secm_session_open_cmd(sec_mod_st *sec, int fd, const SecmSessionOpenM
 	if (sec->config_module && sec->config_module->get_sup_config) {
 		ret = sec->config_module->get_sup_config(sec->config, e, &rep, lpool);
 		if (ret < 0) {
-			seclog(sec, LOG_ERR, "error reading additional configuration for '%s' "SESSION_STR, e->acct_info.username, e->acct_info.psid);
+			seclog(sec, LOG_ERR, "error reading additional configuration for '%s' "SESSION_STR, e->acct_info.username, e->acct_info.safe_id);
 			talloc_free(lpool);
 			return send_failed_session_open_reply(sec, fd);
 		}
@@ -500,7 +498,7 @@ int handle_secm_session_open_cmd(sec_mod_st *sec, int fd, const SecmSessionOpenM
 	}
 	talloc_free(lpool);
 
-	seclog(sec, LOG_INFO, "initiating session for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.psid);
+	seclog(sec, LOG_INFO, "initiating session for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.safe_id);
 	e->time = -1;
 	e->in_use++;
 
@@ -521,16 +519,14 @@ int handle_secm_session_close_cmd(sec_mod_st *sec, int fd, const SecmSessionClos
 
 	e = find_client_entry(sec, req->sid.data);
 	if (e == NULL) {
-		char tmp[BASE64_ENCODE_RAW_LENGTH(SID_SIZE) + 1];
-		oc_base64_encode((char *)req->sid.data, req->sid.len, (char *)tmp, sizeof(tmp));
-		seclog(sec, LOG_INFO, "session close but with non-existing SID: %s", tmp);
+		seclog(sec, LOG_INFO, "session close but with non-existing SID");
 		return send_msg(e, fd, CMD_SECM_CLI_STATS, &rep,
 		                (pack_size_func) cli_stats_msg__get_packed_size,
 		                (pack_func) cli_stats_msg__pack);
 	}
 
 	if (e->status < PS_AUTH_COMPLETED) {
-		seclog(sec, LOG_DEBUG, "session close received in unauthenticated client %s "SESSION_STR"!", e->acct_info.username, e->acct_info.psid);
+		seclog(sec, LOG_DEBUG, "session close received in unauthenticated client %s "SESSION_STR"!", e->acct_info.username, e->acct_info.safe_id);
 		return send_msg(e, fd, CMD_SECM_CLI_STATS, &rep,
 		                (pack_size_func) cli_stats_msg__get_packed_size,
 		                (pack_func) cli_stats_msg__pack);
@@ -610,14 +606,12 @@ int handle_sec_auth_stats_cmd(sec_mod_st * sec, const CliStatsMsg * req, pid_t p
 
 	e = find_client_entry(sec, req->sid.data);
 	if (e == NULL) {
-		char tmp[BASE64_ENCODE_RAW_LENGTH(SID_SIZE) + 1];
-		oc_base64_encode((char *)req->sid.data, req->sid.len, (char *)tmp, sizeof(tmp));
-		seclog(sec, LOG_INFO, "session stats but with non-existing SID: %s", tmp);
+		seclog(sec, LOG_INFO, "session stats but with non-existing SID");
 		return -1;
 	}
 
 	if (e->status != PS_AUTH_COMPLETED) {
-		seclog(sec, LOG_ERR, "session stats received in unauthenticated client %s "SESSION_STR"!", e->acct_info.username, e->acct_info.psid);
+		seclog(sec, LOG_ERR, "session stats received in unauthenticated client %s "SESSION_STR"!", e->acct_info.username, e->acct_info.safe_id);
 		return -1;
 	}
 
@@ -671,16 +665,16 @@ int handle_sec_auth_cont(int cfd, sec_mod_st * sec, const SecAuthContMsg * req)
 
 	if (e->status != PS_AUTH_INIT && e->status != PS_AUTH_CONT) {
 		seclog(sec, LOG_ERR, "auth cont received for %s "SESSION_STR" but we are on state %u!",
-		       e->acct_info.username, e->acct_info.psid, e->status);
+		       e->acct_info.username, e->acct_info.safe_id, e->status);
 		ret = -1;
 		goto cleanup;
 	}
 
-	seclog(sec, LOG_DEBUG, "auth cont for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.psid);
+	seclog(sec, LOG_DEBUG, "auth cont for user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.safe_id);
 
 	if (req->password == NULL) {
 		seclog(sec, LOG_ERR, "no password given in auth cont for user '%s' "SESSION_STR,
-			e->acct_info.username, e->acct_info.psid);
+			e->acct_info.username, e->acct_info.safe_id);
 		ret = -1;
 		goto cleanup;
 	}
@@ -700,7 +694,7 @@ int handle_sec_auth_cont(int cfd, sec_mod_st * sec, const SecAuthContMsg * req)
 		if (ret != ERR_AUTH_CONTINUE) {
 			seclog(sec, LOG_DEBUG,
 			       "error in password given in auth cont for user '%s' "SESSION_STR,
-			       e->acct_info.username, e->acct_info.psid);
+			       e->acct_info.username, e->acct_info.safe_id);
 		}
 		goto cleanup;
 	}
@@ -724,7 +718,7 @@ int set_module(sec_mod_st * sec, client_entry_st *e, unsigned auth_type)
 			e->module = sec->perm_config->auth[i].amod;
 			e->auth_type = sec->perm_config->auth[i].type;
 
-			seclog(sec, LOG_INFO, "using '%s' authentication to authenticate user "SESSION_STR, sec->perm_config->auth[i].name, e->acct_info.psid);
+			seclog(sec, LOG_INFO, "using '%s' authentication to authenticate user "SESSION_STR, sec->perm_config->auth[i].name, e->acct_info.safe_id);
 			return 0;
 		}
 	}
@@ -802,7 +796,7 @@ int handle_sec_auth_init(int cfd, sec_mod_st *sec, const SecAuthInitMsg *req, pi
 	e->status = PS_AUTH_INIT;
 	seclog(sec, LOG_DEBUG, "auth init %sfor user '%s' "SESSION_STR" of group: '%s' from '%s'", 
 	       req->tls_auth_ok?"(with cert) ":"",
-	       e->acct_info.username, e->acct_info.psid, e->acct_info.groupname, req->ip);
+	       e->acct_info.username, e->acct_info.safe_id, e->acct_info.groupname, req->ip);
 
 	if (need_continue != 0) {
 		ret = ERR_AUTH_CONTINUE;
@@ -816,7 +810,7 @@ int handle_sec_auth_init(int cfd, sec_mod_st *sec, const SecAuthInitMsg *req, pi
 
 void sec_auth_user_deinit(sec_mod_st *sec, client_entry_st *e)
 {
-	seclog(sec, LOG_DEBUG, "permamently closing session of user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.psid);
+	seclog(sec, LOG_DEBUG, "permamently closing session of user '%s' "SESSION_STR, e->acct_info.username, e->acct_info.safe_id);
 	if (sec->perm_config->acct.amod != NULL && sec->perm_config->acct.amod->close_session != NULL && e->session_is_open != 0) {
 		sec->perm_config->acct.amod->close_session(e->auth_type, &e->acct_info, &e->saved_stats, e->discon_reason);
 	}
